cheesecake.cheesecake_index.NameSetter

Package cheesecake :: Module cheesecake_index :: Class NameSetter |
[show private | hide private]
[frames | no frames]

## Type NameSetter

    object --+
             |
          type --+
                 |
                NameSetter

Method Summary
| `__init__(cls, name, bases, dict)`
| `__repr__(cls)`
Inherited from type
| ``__call__`(x, ...)` x.__call__(...) <==> x(...)
| ``__cmp__`(x, y)` x.__cmp__(y) <==> cmp(x,y)
| ``__delattr__`(...)` x.__delattr__('name') <==> del x.name
| ``__getattribute__`(...)` x.__getattribute__('name') <==> x.name
| ``__hash__`(x)` x.__hash__() <==> hash(x)
| ``__new__`(T, S, ...)` T.__new__(S, ...) -> a new object with type S, a subtype of T
| ``__setattr__`(...)` x.__setattr__('name', value) <==> x.name = value
list of immediate subclasses | ``__subclasses__`()` __subclasses__() -> list of immediate subclasses
list | ``mro`()` return a type's method resolution order
Inherited from object
| ``__reduce__`(...)` helper for pickle
| ``__reduce_ex__`(...)` helper for pickle
| ``__str__`(x)` x.__str__() <==> str(x)

Class Variable Summary
Inherited from type
`tuple` | `__bases__` = `(<type 'object'>,)`
`int` | `__basicsize__` = 420
`int` | `__dictoffset__` = 132
`int` | `__flags__` = 21995
`int` | `__itemsize__` = 20
`tuple` | `__mro__` = `(<type 'type'>, <type 'object'>)`
`str` | `__name__` = `'type'`
`int` | `__weakrefoffset__` = 184

Generated by Epydoc 2.1 on Fri Feb 9 02:15:13 2007 | http://epydoc.sf.net